/** 
 * @file  SFMT-sse2.h
 * @brief header file for SFMT algorithm
 *
 * @author Christophe Dutang
 *
 *
 * Copyright (C) 2009, Christophe Dutang. 
 * All rights reserved.
 *
 * The new BSD License is applied to this software.
 * Copyright (c) 2009 Christophe Dutang. 
 * All rights reserved.
 *
 *      Redistribution and use in source and binary forms, with or without
 *      modification, are permitted provided that the following conditions are
 *      met:
 *      
 *          - Redistributions of source code must retain the above copyright
 *          notice, this list of conditions and the following disclaimer.
 *          - Redistributions in binary form must reproduce the above
 *          copyright notice, this list of conditions and the following
 *          disclaimer in the documentation and/or other materials provided
 *          with the distribution.
 *          - Neither the names of its contributors may be used to endorse or promote 
 *          products derived from this software without specific prior written
 *          permission.
 *     
 *      THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *      "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *      LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *      A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *      OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *      SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *      LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *      DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *      THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *      (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *      OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
/*****************************************************************************
 *  call headers of Matsumoto and Saito
 *
 *		header
 *
 */
/*
#ifndef SFMT_SSE2_H
#define SFMT_SSE2_H

#include "SFMT-sse2-607-1.h"
#include "SFMT-sse2-607-2.h"
#include "SFMT-sse2-607-3.h"
#include "SFMT-sse2-607-4.h"
#include "SFMT-sse2-607-5.h"
#include "SFMT-sse2-607-6.h"
#include "SFMT-sse2-607-7.h"
#include "SFMT-sse2-607-8.h"
#include "SFMT-sse2-607-9.h"
#include "SFMT-sse2-607-10.h"
#include "SFMT-sse2-607-11.h"
#include "SFMT-sse2-607-12.h"
#include "SFMT-sse2-607-13.h"
#include "SFMT-sse2-607-14.h"
#include "SFMT-sse2-607-15.h"
#include "SFMT-sse2-607-16.h"
#include "SFMT-sse2-607-17.h"
#include "SFMT-sse2-607-18.h"
#include "SFMT-sse2-607-19.h"
#include "SFMT-sse2-607-20.h"
#include "SFMT-sse2-607-21.h"
#include "SFMT-sse2-607-22.h"
#include "SFMT-sse2-607-23.h"
#include "SFMT-sse2-607-24.h"
#include "SFMT-sse2-607-25.h"
#include "SFMT-sse2-607-26.h"
#include "SFMT-sse2-607-27.h"
#include "SFMT-sse2-607-28.h"
#include "SFMT-sse2-607-29.h"
#include "SFMT-sse2-607-30.h"
#include "SFMT-sse2-607-31.h"
#include "SFMT-sse2-607-32.h"

#include "SFMT-sse2-1279-1.h"
#include "SFMT-sse2-2281-1.h"
#include "SFMT-sse2-4253-1.h"
#include "SFMT-sse2-11213-1.h"
#include "SFMT-sse2-19937-1.h"

#include "SFMT-sse2-44497-1.h"
#include "SFMT-sse2-86243-1.h"
#include "SFMT-sse2-132049-1.h"
#include "SFMT-sse2-216091-1.h"

#endif */

